@@ -20,9 +20,10 @@
 void MD5Info::destroy()
 {
   OpenMP::ScopedLock instantiateLock(s_instanceLock);
-	if(s_instance)
+	if(s_instance) {
 		delete s_instance;
-	else
+	} else {
 		_debugLevel1("Already destroyed, but not a problem.");
+	}
 	s_instance = 0;
 }
