@@ -14,15 +14,15 @@
   You should have received a copy of the GNU General Public License
   along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
 */
-
 #include "arguments.ih"
 
 void Arguments::destroy()
 {
   OpenMP::ScopedLock instantiateLock(s_instanceLock);
-	if(s_instance)
+	if(s_instance) {
 		delete s_instance;
-	else
+	} else {
 		_debugLevel1("Already destroyed!!");
+	}
 	s_instance = 0;
 }
