@@ -19,16 +19,16 @@
 
 bool FileSystem::isDirectory(std::string const &filename)
 {
-  OpenMP::ScopedLock asdf(fsLock);
+    OpenMP::ScopedLock scopedFsLock(fsLock);
 
-	struct stat a;
-	int rcode = stat(filename.c_str(), &a);
+    struct stat a;
+    int rcode = stat(filename.c_str(), &a);
 
-	if(rcode != 0) //Stat failed
-	  return false;
+    if(rcode != 0) //Stat failed
+       return false;
 
-	if(S_ISDIR(a.st_mode))
-	  return true;
+    if(S_ISDIR(a.st_mode))
+       return true;
 
-	return false;
+    return false;
 }
