@@ -16,7 +16,7 @@
 */
 #include "globals.ih"
 
-std::string * const Globals::operator[](std::string const &global)
+std::string const * Globals::operator[](std::string const &global)
 {
 	string *p = d_map[global];
 	if(p == 0)
