@@ -19,9 +19,11 @@
 void Resolver::destroy()
 {
   OpenMP::ScopedLock instantiateLock(s_instanceLock);
-	if(s_instance)
+	if(s_instance) {
 		delete s_instance;
-	else
+	}
+	else {
 		_debugLevel1("Already destroyed!!");
+	}
 	s_instance = 0;
 }
