@@ -19,10 +19,11 @@
 
 void Sources::destroy()
 {
-  OpenMP::ScopedLock instantiateLock(s_instanceLock);
-	if(s_instance)
-		delete s_instance;
-	else
-		_debugLevel1("Already destoryed!!");
-	s_instance = 0;
+    OpenMP::ScopedLock instantiateLock(s_instanceLock);
+    if(s_instance) {
+        delete s_instance;
+    } else {
+        _debugLevel1("Already destoryed!!");
+    }
+    s_instance = 0;
 }
